@@ -15,13 +15,17 @@
 #   
 #   You should have received a copy of the GNU General Public License
 #   along with this program; if not, write to the Free Software
-#   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+#   Foundation, Inc.,  51 Franklin Street, Fifth Floor, Boston, MA
+#   02110-1301 USA
 #
 ###################################################################
 
 minimum.spanning.tree <- function(graph, weights=NULL,
                                   algorithm="unweighted", ...) {
 
+  if (!is.igraph(graph)) {
+    stop("Not a graph object")
+  }
   if (algorithm=="unweighted") {
     .Call("R_igraph_minimum_spanning_tree_unweighted", graph,
           PACKAGE="igraph")
