@@ -16,7 +16,8 @@
    
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+   02110-1301 USA
 
 */
 
@@ -38,28 +39,64 @@ int igraph_i_adjlist_init(const igraph_t *graph, igraph_i_adjlist_t *al,
   if (al->adjs == 0) {
     IGRAPH_ERROR("Cannot create adjlist view", IGRAPH_ENOMEM);
   }
-  IGRAPH_FINALLY(igraph_free, al->adjs);
 
-  IGRAPH_FINALLY(igraph_i_adjlist_destroy, al);  
+  IGRAPH_FINALLY(igraph_i_adjlist_destroy, al);
   for (i=0; i<al->length; i++) {
+    IGRAPH_ALLOW_INTERRUPTION();
     IGRAPH_CHECK(igraph_vector_init(&al->adjs[i], 0));
     IGRAPH_CHECK(igraph_neighbors(graph, &al->adjs[i], i, mode));
   }
-  
-  IGRAPH_FINALLY_CLEAN(2);
+
+  IGRAPH_FINALLY_CLEAN(1);
   return 0;
 }
 
 void igraph_i_adjlist_destroy(igraph_i_adjlist_t *al) {
   long int i;
   for (i=0; i<al->length; i++) {
-    /* This works if some igraph_vector_t's are 0, because igraph_vector_destroy can
-       handle this. */
     igraph_vector_destroy(&al->adjs[i]);
   }
   Free(al->adjs);
 }
 
-/* igraph_vector_t *igraph_i_adjlist_get(igraph_i_adjlist_t *al, integer_t no) { */
+/* igraph_vector_t *igraph_i_adjlist_get(igraph_i_adjlist_t *al, igraph_integer_t no) { */
 /*   return &al->adjs[(long int)no]; */
 /* } */
+
+int igraph_i_adjedgelist_init(const igraph_t *graph, 
+			      igraph_i_adjedgelist_t *ael, 
+			      igraph_neimode_t mode) {
+  long int i;
+
+  if (mode != IGRAPH_IN && mode != IGRAPH_OUT && mode != IGRAPH_ALL) {
+    IGRAPH_ERROR("Cannot create adjedgelist view", IGRAPH_EINVMODE);
+  }
+
+  if (!igraph_is_directed(graph)) { mode=IGRAPH_ALL; }
+
+  ael->length=igraph_vcount(graph);
+  ael->adjs=Calloc(ael->length, igraph_vector_t);
+  if (ael->adjs == 0) {
+    IGRAPH_ERROR("Cannot create adjedgelist view", IGRAPH_ENOMEM);
+  }
+
+  IGRAPH_FINALLY(igraph_i_adjlist_destroy, ael);  
+  for (i=0; i<ael->length; i++) {
+    IGRAPH_ALLOW_INTERRUPTION();
+    IGRAPH_CHECK(igraph_vector_init(&ael->adjs[i], 0));
+    IGRAPH_CHECK(igraph_adjacent(graph, &ael->adjs[i], i, mode));
+  }
+  
+  IGRAPH_FINALLY_CLEAN(1);
+  return 0;
+}
+
+void igraph_i_adjedgelist_destroy(igraph_i_adjedgelist_t *ael) {
+  long int i;
+  for (i=0; i<ael->length; i++) {
+    /* This works if some igraph_vector_t's are 0, because igraph_vector_destroy can
+       handle this. */
+    igraph_vector_destroy(&ael->adjs[i]);
+  }
+  Free(ael->adjs);
+}
